# History of changes


## Version 0.4.2 (2017-08-24)

### Issues Closed

#### Bugs fixed

* [Issue 119](https://github.com/OpenWaterAnalytics/pyswmm/issues/119) - Update SWMM Library
* [Issue 115](https://github.com/OpenWaterAnalytics/pyswmm/issues/115) - execute() method

In this release 2 issues were closed.

## Version 0.4.1 (2017-08-09)


### Pull Requests Merged

* [PR 113](https://github.com/OpenWaterAnalytics/pyswmm/pull/113) - Bug Fixes

In this release 1 pull request was closed.

## Version 0.4.0 (2017-07-14)


### Pull Requests Merged

* [PR 106](https://github.com/OpenWaterAnalytics/pyswmm/pull/106) - Updatetests
* [PR 103](https://github.com/OpenWaterAnalytics/pyswmm/pull/103) - Linux
* [PR 97](https://github.com/OpenWaterAnalytics/pyswmm/pull/97) - Statsfix

In this release 3 pull requests were closed.

## Version 0.3.4 (2017-05-08)


### Pull Requests Merged

* [PR 89](https://github.com/OpenWaterAnalytics/pyswmm/pull/89) - added Simulation.percent_complete property and fixed function name

In this release 1 pull request was closed.


## Version 0.3.3 (2017/05/05)


### Pull Requests Merged

* [PR 86](https://github.com/OpenWaterAnalytics/pyswmm/pull/86) - Support for SWMM 5.1.12 and exposed error and engine version properties
* [PR 81](https://github.com/OpenWaterAnalytics/pyswmm/pull/81) - Python 3 Support

In this release 2 pull requests were closed.


## Version 0.3.2 (2017/03/13)


### Pull Requests Merged

* [PR 78](https://github.com/OpenWaterAnalytics/pyswmm/pull/78) - added SWMM5 engine selector

In this release 1 pull request was closed.

## Version 0.3.1 (2017/03/10)


### Pull Requests Merged

* [PR 76](https://github.com/OpenWaterAnalytics/pyswmm/pull/76) - re-compiled SWMM to fix set simulation time functions
* [PR 73](https://github.com/OpenWaterAnalytics/pyswmm/pull/73) - updated default save to bin file
* [PR 70](https://github.com/OpenWaterAnalytics/pyswmm/pull/70) - PR: Update readme

In this release 3 pull requests were closed.


## Version 0.3 (2017/02/24)

### Issues Closed

#### New Features

* [Issue 63](https://github.com/OpenWaterAnalytics/pyswmm/issues/63) - updates to Simulation.py
* [Issue 27](https://github.com/OpenWaterAnalytics/pyswmm/issues/27) - Enhancements to pyswmm.Simulation base classes

#### Bugs fixed

* [Issue 55](https://github.com/OpenWaterAnalytics/pyswmm/issues/55) - import update bug fix for py2.7
* [Issue 48](https://github.com/OpenWaterAnalytics/pyswmm/issues/48) - Fix Docs

In this release 4 issues were closed.

### Pull Requests Merged

* [PR 69](https://github.com/OpenWaterAnalytics/pyswmm/pull/69) - hot fix - subcatchments
* [PR 68](https://github.com/OpenWaterAnalytics/pyswmm/pull/68) - PR: Fix code style
* [PR 67](https://github.com/OpenWaterAnalytics/pyswmm/pull/67) - added subcatchments.py module
* [PR 66](https://github.com/OpenWaterAnalytics/pyswmm/pull/66) - turned off reader module
* [PR 62](https://github.com/OpenWaterAnalytics/pyswmm/pull/62) - Updated Simulation Docs and Added Current Time Function
* [PR 61](https://github.com/OpenWaterAnalytics/pyswmm/pull/61) - PR: Report coverage
* [PR 58](https://github.com/OpenWaterAnalytics/pyswmm/pull/58) - PR: Fix/ci
* [PR 57](https://github.com/OpenWaterAnalytics/pyswmm/pull/57) - Updates to docs
* [PR 56](https://github.com/OpenWaterAnalytics/pyswmm/pull/56) - Fix import for py2.7
* [PR 53](https://github.com/OpenWaterAnalytics/pyswmm/pull/53) - #48 Updates to docs
* [PR 49](https://github.com/OpenWaterAnalytics/pyswmm/pull/49) - Bug Fix All API Enum Arguments
* [PR 45](https://github.com/OpenWaterAnalytics/pyswmm/pull/45) - PR: Add release process workflow
* [PR 43](https://github.com/OpenWaterAnalytics/pyswmm/pull/43) - PR: Add code style automatic checks on appveyor
* [PR 41](https://github.com/OpenWaterAnalytics/pyswmm/pull/41) - PR: Clean up code and imports
* [PR 39](https://github.com/OpenWaterAnalytics/pyswmm/pull/39) - PR: Include the output toolkit api
* [PR 38](https://github.com/OpenWaterAnalytics/pyswmm/pull/38) - PR: Clean up code and docs style and clean imports
* [PR 37](https://github.com/OpenWaterAnalytics/pyswmm/pull/37) - Added Link Connection and type helper functions
* [PR 30](https://github.com/OpenWaterAnalytics/pyswmm/pull/30) - Add manifest for pypi packaging
* [PR 29](https://github.com/OpenWaterAnalytics/pyswmm/pull/29) - enhacements to pyswmm.Simulation class
* [PR 28](https://github.com/OpenWaterAnalytics/pyswmm/pull/28) - Add gitattributes, normalize endings
* [PR 24](https://github.com/OpenWaterAnalytics/pyswmm/pull/24) - Add copyright header to files
* [PR 17](https://github.com/OpenWaterAnalytics/pyswmm/pull/17) - Added pyswmm simulation class; restructured and added descriptors
* [PR 3](https://github.com/OpenWaterAnalytics/pyswmm/pull/3) - Enable platform detection and some utilities
* [PR 1](https://github.com/OpenWaterAnalytics/pyswmm/pull/1) - pyswmm house cleaning

In this release 24 pull requests were closed.
